pub enum ClientBuildError {
InvalidHeaderValue(InvalidHeaderValue),
Reqwest(Error),
}Expand description
Error constructing a DoseSpotClient.
The subscription key and access token become HTTP header values, so they must be visible ASCII; building the underlying HTTP client can also fail (e.g. no TLS backend enabled).
Variants
InvalidHeaderValue(InvalidHeaderValue)
The subscription key or access token contains bytes not allowed in an HTTP header.
Reqwest(Error)
The underlying reqwest::Client could not be constructed.